SYMBOL_TYPE_SPOT: str
ORDER_STATUS_NEW: str
ORDER_STATUS_PARTIALLY_FILLED: str
ORDER_STATUS_FILLED: str
ORDER_STATUS_CANCELED: str
ORDER_STATUS_PENDING_CANCEL: str
ORDER_STATUS_REJECTED: str
ORDER_STATUS_EXPIRED: str
KLINE_INTERVAL_1SECOND: str
KLINE_INTERVAL_1MINUTE: str
KLINE_INTERVAL_3MINUTE: str
KLINE_INTERVAL_5MINUTE: str
KLINE_INTERVAL_15MINUTE: str
KLINE_INTERVAL_30MINUTE: str
KLINE_INTERVAL_1HOUR: str
KLINE_INTERVAL_2HOUR: str
KLINE_INTERVAL_4HOUR: str
KLINE_INTERVAL_6HOUR: str
KLINE_INTERVAL_8HOUR: str
KLINE_INTERVAL_12HOUR: str
KLINE_INTERVAL_1DAY: str
KLINE_INTERVAL_3DAY: str
KLINE_INTERVAL_1WEEK: str
KLINE_INTERVAL_1MONTH: str
SIDE_BUY: str
SIDE_SELL: str
ORDER_TYPE_LIMIT: str
ORDER_TYPE_MARKET: str
ORDER_TYPE_STOP_LOSS: str
ORDER_TYPE_STOP_LOSS_LIMIT: str
ORDER_TYPE_TAKE_PROFIT: str
ORDER_TYPE_TAKE_PROFIT_LIMIT: str
ORDER_TYPE_LIMIT_MAKER: str
FUTURE_ORDER_TYPE_LIMIT: str
FUTURE_ORDER_TYPE_MARKET: str
FUTURE_ORDER_TYPE_STOP: str
FUTURE_ORDER_TYPE_STOP_MARKET: str
FUTURE_ORDER_TYPE_TAKE_PROFIT: str
FUTURE_ORDER_TYPE_TAKE_PROFIT_MARKET: str
FUTURE_ORDER_TYPE_LIMIT_MAKER: str
TIME_IN_FORCE_GTC: str
TIME_IN_FORCE_IOC: str
TIME_IN_FORCE_FOK: str
TIME_IN_FORCE_GTX: str
ORDER_RESP_TYPE_ACK: str
ORDER_RESP_TYPE_RESULT: str
ORDER_RESP_TYPE_FULL: str
